@@ -21,7 +21,8 @@ from functions_record import *
 
 #load language file
 import i18n
-_ = i18n.language.gettext
+#_ = i18n.language.gettext
+_ = i18n.language.ugettext
 
 ###########################################################################
 ## Function to open or close the record file
