@@ -15,17 +15,25 @@ def IsCompiled():
 
 
 
-def sleep_filter(ar, l, filter,  shift, scale, max, min):
+def sleep_filter(ar, l, filter,  shift, scale, max, min, limitMovement):
     len_filter=len(filter)
 
     ar_ret=[0]*(l+len_filter)
 
+    for i in range(0, l-1): #loop arrData
+        if(ar[i] > limitMovement): #limit peack values
+            ar[i] = limitMovement
+
+
+
     for i in range(0, l-1): #loop arrData
         value=ar[i]
 
         for p in range(0,  len_filter-1): #loop arrFilter
             ar_ret[i+p-shift] = ar_ret[i+p-shift] + value*filter[p]
 
+
+
     for i in range(0, l-1): #loop arrData
         value=ar_ret[i] / (scale*100) #autoscale
 
@@ -47,4 +55,4 @@ if __name__ == '__main__':
     IsCompiled()
     arTest=[1, 2, 3, 4, 5, 6, 7, 8, 9]
     arFiltertest=[1, 2, 3]
-    sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13)
+    sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13, 250)
