@@ -42,6 +42,10 @@ try:
 except:
     print "Version file not found, please check your installation!"
 
+
+import kht_report  #Used for error reporting
+
+
 #check parameters
 if(len(sys.argv)>1):  #at least one parameter
     if(sys.argv[1]=="debug"):
@@ -98,6 +102,52 @@ from Ui_AdditionalInfoWindow import *
 
 
 
+
+class MyMainWindow(QWidget):
+	def __init__(self):
+		QWidget.__init__(self, None)
+
+		vbox = QVBoxLayout()
+
+		b = QPushButton("Push me!")
+		vbox.addWidget(b)
+
+		self.connect(b, SIGNAL("clicked()"), self.buttonPushed)
+
+		self.setLayout(vbox)
+
+	def buttonPushed(self):
+		d = QDialog(self)
+
+		vbox = QVBoxLayout()
+		#Add Layouts
+		horizontalLayout = QHBoxLayout()
+		horizontalLayout1 = QHBoxLayout()
+
+		# Now create your buttons.
+		b = QPushButton("Close window")
+		c = QPushButton("Die")
+		e = QPushButton("In Fires")
+		f = QPushButton("With Chickens!")
+
+		self.connect(b, SIGNAL("clicked()"), d.close)
+
+		# Add buttons to your layouts, they'll show up in the order given.
+		horizontalLayout1.addWidget(f)
+		horizontalLayout1.addWidget(b)
+		horizontalLayout.addWidget(c)
+		horizontalLayout.addWidget(e)
+
+		# Add layouts to your main Layout
+		vbox.addLayout (horizontalLayout)
+		vbox.addLayout (horizontalLayout1)
+		d.setLayout(vbox)
+
+		# Show the window!
+		d.show()
+
+
+
 ###########################################################################
 ## Main function
 ##############o#############################################################
@@ -112,6 +162,10 @@ def main():
 
     app = QApplication(sys.argv)
 
+
+    kht_report.install_excepthook("SleepAnalyser", data.version +"-"+ data.build)
+
+
     if(data.debug==True): print "Application path:",  data.app_path
 
     if(data.demo==True):
@@ -124,7 +178,6 @@ def main():
     config=LoadConfig()
 
 
-
     #chek if module is available and could get loaded
     if(MyLib_Imported==True): #module is loaded
         print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
@@ -178,6 +231,7 @@ def main():
 
 
 
+
     StartWindow = frmStartWindow()
     StartWindow.show()
     StartWindow.UpdateScreenStart()
@@ -342,7 +396,6 @@ def InitMeasurement():
 #    data.interval=1 #Debugging
 
 
-
     data.run=True #change to recording
     app.timer_GetData = QtCore.QTimer()
     QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), MeasurementTimerLoop)
@@ -1066,7 +1119,6 @@ class frmViewWindow(QMainWindow):
 
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
 
-
         self.ui.lblStatus.hide()
         self.Canvas.show()
         self.StatisticsCanvas.show()
